@@ -2,6 +2,13 @@ from datetime import datetime
 from enum import Enum
 from typing import Dict, List, Optional, Union
 
+from mypy_boto3_athena import AthenaClient
+from mypy_boto3_glue import GlueClient
+from mypy_boto3_s3 import S3Client, S3ServiceResource
+from mypy_boto3_secretsmanager import SecretsManagerClient
+from mypy_boto3_ses import SESClient
+from mypy_boto3_sqs import SQSClient
+
 from pydantic import BaseModel, EmailStr, validator
 
 #
@@ -9,6 +16,41 @@ from pydantic import BaseModel, EmailStr, validator
 #
 
 
+class Config(BaseModel):
+    cache_update_threshold: int
+    cookie_max_age_days: int
+    cookie_security: bool
+    cors_allow_origin: str
+    honeycomb_secret_id: str  # honeycomb.io API key
+    jwt_name: str  # jwt-ci | jwt-dev | jwt-prod
+    jwt_algorithm: str  # ES256
+    jwt_audience: str  # DatadeftDev | DepoxyProd | HexaLoc | Etc.
+    jwt_secret_id: str  # SecretsManager secret id for Signing key
+    s3_bucket: str
+    ses_sender_address: str
+    stage: str
+
+
+class Clients:
+    def __init__(
+        self,
+        s3_client: S3Client,
+        s3_resource: S3ServiceResource,
+        sqs_client: SQSClient,
+        secretsmanager_client: SecretsManagerClient,
+        glue_client: GlueClient,
+        ses_client: SESClient,
+        athena_client: AthenaClient,
+    ):
+        self.s3_client = s3_client
+        self.s3_resource = s3_resource
+        self.sqs_client = sqs_client
+        self.secretsmanager_client = secretsmanager_client
+        self.glue_client = glue_client
+        self.ses_client = ses_client
+        self.athena_client = athena_client
+
+
 class CustomError(BaseModel):
     message: str
     reasons: List[str]
@@ -214,7 +256,7 @@ class QuerySummary(BaseModel):
     queryState: str
     queryStart: str  # TODO: validator
     queryRunTimeMs: int
-    queryDataScanned: int
+    queryDataScannedInMiB: float
 
 
 class QuerySummaries(BaseModel):
@@ -223,7 +265,7 @@ class QuerySummaries(BaseModel):
 
 class Statistics(BaseModel):
     engineExecutionTime: int
-    dataScannedInBytes: int
+    dataScannedInMiB: float
     totalExecutionTime: int
     queryQueueTime: int
     queryPlanningTime: Optional[int]
